@@ -7,6 +7,9 @@
 //  http://www.boost.org/LICENSE_1_0.txt)
 //
 
+#ifndef UBLAS_H_
+#define UBLAS_H_
+
 #define BOOST_UBLAS_NDEBUG
 #include <boost/numeric/ublas/vector.hpp>
 #include <boost/numeric/ublas/vector_proxy.hpp>
@@ -18,6 +21,7 @@ typedef std::size_t Size;
 namespace ublas = boost::numeric::ublas;
 
 //#include <stdint.h>
-
 //typedef long long long_long_type;
 //typedef unsigned long long ulong_long_type;
+
+#endif // UBLAS_H_
